aboutsummaryrefslogtreecommitdiffstats
path: root/components/layout_2020/fragment_tree/fragment_tree.rs
diff options
context:
space:
mode:
authorEuclid Ye <yezhizhenjiakang@gmail.com>2025-02-14 18:18:25 +0800
committerGitHub <noreply@github.com>2025-02-14 10:18:25 +0000
commit3e1d15da9b1777173d2fad9c2cc63232e1d4d55e (patch)
tree37bb5e23ffa176973fe2593a4036a212d13ac837 /components/layout_2020/fragment_tree/fragment_tree.rs
parent03fc54e682bceebeece0ee556c25b8c9b897726f (diff)
downloadservo-3e1d15da9b1777173d2fad9c2cc63232e1d4d55e.tar.gz
servo-3e1d15da9b1777173d2fad9c2cc63232e1d4d55e.zip
Fix scroll_sensitivity related naming issue (#35462)
Signed-off-by: Euclid Ye <yezhizhenjiakang@gmail.com>
Diffstat (limited to 'components/layout_2020/fragment_tree/fragment_tree.rs')
-rw-r--r--components/layout_2020/fragment_tree/fragment_tree.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/components/layout_2020/fragment_tree/fragment_tree.rs b/components/layout_2020/fragment_tree/fragment_tree.rs
index 5d682227648..a620d0b1f9f 100644
--- a/components/layout_2020/fragment_tree/fragment_tree.rs
+++ b/components/layout_2020/fragment_tree/fragment_tree.rs
@@ -37,8 +37,8 @@ pub struct FragmentTree {
/// <https://drafts.csswg.org/css-backgrounds/#special-backgrounds>
pub(crate) canvas_background: CanvasBackground,
- /// Whether or not the root element is sensitive to scroll input events.
- pub root_scroll_sensitivity: AxesScrollSensitivity,
+ /// Whether or not the viewport is sensitive to scroll input events.
+ pub viewport_scroll_sensitivity: AxesScrollSensitivity,
}
impl FragmentTree {